@@ -87,12 +87,10 @@ class PhotoMixin(pim.ContentItem):
             takenString = str(exif.get('EXIF DateTimeOriginal',
                               exif['Image DateTime']))
 
-            timestamp = time.mktime(time.strptime(takenString,
-                                                  "%Y:%m:%d %H:%M:%S"))
-            self.dateTaken = datetime.fromtimestamp(timestamp)
-            if self.dateTaken.tzinfo is None:
-                self.dateTaken = self.dateTaken.replace(tzinfo=self.itsView.tzinfo.default)
-
+            timetuple = time.strptime(takenString, "%Y:%m:%d %H:%M:%S")
+            dt_keywords = dict(tzinfo=self.itsView.tzinfo.default)
+            
+            self.dateTaken = datetime(*timetuple[:6], **dt_keywords)
             self.exif = {}
             for (key, value) in exif.iteritems():
                 if isinstance(value, EXIF.IFD_Tag):
